==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/inputs/PrivateLinkResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.inputs

import com.pulumi.azurenative.containerservice.inputs.PrivateLinkResourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A private link resource
 * @property groupId The group ID of the resource.
 * @property id The ID of the private link resource.
 * @property name The name of the private link resource.
 * @property requiredMembers The RequiredMembers of the resource
 * @property type The resource type.
 */
public data class PrivateLinkResourceArgs(
    public val groupId: Output<String>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val requiredMembers: Output<List<String>>? = null,
    public val type: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerservice.inputs.PrivateLinkResourceArgs> {
    override fun toJava(): com.pulumi.azurenative.containerservice.inputs.PrivateLinkResourceArgs =
        com.pulumi.azurenative.containerservice.inputs.PrivateLinkResourceArgs.builder()
            .groupId(groupId?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .requiredMembers(requiredMembers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .type(type?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PrivateLinkResourceArgs].
 */
@PulumiTagMarker
public class PrivateLinkResourceArgsBuilder internal constructor() {
    private var groupId: Output<String>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var requiredMembers: Output<List<String>>? = null

    private var type: Output<String>? = null

    /**
     * @param value The group ID of the resource.
     */
    @JvmName("vdlsxvcggibiijhi")
    public suspend fun groupId(`value`: Output<String>) {
        this.groupId = value
    }

    /**
     * @param value The ID of the private link resource.
     */
    @JvmName("aoviogkknjyftivr")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the private link resource.
     */
    @JvmName("teqfebvjnevvcucb")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The RequiredMembers of the resource
     */
    @JvmName("yopvkpkwilrxhqcb")
    public suspend fun requiredMembers(`value`: Output<List<String>>) {
        this.requiredMembers = value
    }

    @JvmName("uywhtmeoqfuyurre")
    public suspend fun requiredMembers(vararg values: Output<String>) {
        this.requiredMembers = Output.all(values.asList())
    }

    /**
     * @param values The RequiredMembers of the resource
     */
    @JvmName("morliytaiiytdujb")
    public suspend fun requiredMembers(values: List<Output<String>>) {
        this.requiredMembers = Output.all(values)
    }

    /**
     * @param value The resource type.
     */
    @JvmName("evqrbmymphebrmnh")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The group ID of the resource.
     */
    @JvmName("hmlhuvevganpfkgp")
    public suspend fun groupId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupId = mapped
    }

    /**
     * @param value The ID of the private link resource.
     */
    @JvmName("yjbxklaowyfsxpby")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the private link resource.
     */
    @JvmName("fvcuybeyqxccddix")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The RequiredMembers of the resource
     */
    @JvmName("dyudgrewtobfrfuk")
    public suspend fun requiredMembers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requiredMembers = mapped
    }

    /**
     * @param values The RequiredMembers of the resource
     */
    @JvmName("ufolxvrkxmnfrmpf")
    public suspend fun requiredMembers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requiredMembers = mapped
    }

    /**
     * @param value The resource type.
     */
    @JvmName("lypjchvydxnlkovy")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): PrivateLinkResourceArgs = PrivateLinkResourceArgs(
        groupId = groupId,
        id = id,
        name = name,
        requiredMembers = requiredMembers,
        type = type,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/inputs/PrivateLinkResourceArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.inputs

import com.pulumi.azurenative.containerservice.inputs.PrivateLinkResourceArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * A private link resource
 * @property groupId The group ID of the resource.
 * @property id The ID of the private link resource.
 * @property name The name of the private link resource.
 * @property requiredMembers The RequiredMembers of the resource
 * @property type The resource type.
 */
public data class PrivateLinkResourceArgs(
    public val groupId: Output<String>? = null,
    public val id: Output<String>? = null,
    public val name: Output<String>? = null,
    public val requiredMembers: Output<List<String>>? = null,
    public val type: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.containerservice.inputs.PrivateLinkResourceArgs> {
    override fun toJava(): com.pulumi.azurenative.containerservice.inputs.PrivateLinkResourceArgs =
        com.pulumi.azurenative.containerservice.inputs.PrivateLinkResourceArgs.builder()
            .groupId(groupId?.applyValue({ args0 -> args0 }))
            .id(id?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .requiredMembers(requiredMembers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .type(type?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [PrivateLinkResourceArgs].
 */
@PulumiTagMarker
public class PrivateLinkResourceArgsBuilder internal constructor() {
    private var groupId: Output<String>? = null

    private var id: Output<String>? = null

    private var name: Output<String>? = null

    private var requiredMembers: Output<List<String>>? = null

    private var type: Output<String>? = null

    /**
     * @param value The group ID of the resource.
     */
    @JvmName("mqpmjihcnhlfhatt")
    public suspend fun groupId(`value`: Output<String>) {
        this.groupId = value
    }

    /**
     * @param value The ID of the private link resource.
     */
    @JvmName("qrvihngnfelouspt")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value The name of the private link resource.
     */
    @JvmName("bsmctgjbdwbkaqrs")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The RequiredMembers of the resource
     */
    @JvmName("gtqtfjricrhtbxkm")
    public suspend fun requiredMembers(`value`: Output<List<String>>) {
        this.requiredMembers = value
    }

    @JvmName("jklhqenjxblgfkhd")
    public suspend fun requiredMembers(vararg values: Output<String>) {
        this.requiredMembers = Output.all(values.asList())
    }

    /**
     * @param values The RequiredMembers of the resource
     */
    @JvmName("hetwdrnpiimmuhpl")
    public suspend fun requiredMembers(values: List<Output<String>>) {
        this.requiredMembers = Output.all(values)
    }

    /**
     * @param value The resource type.
     */
    @JvmName("nxusjmdvcwvrlkvr")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value The group ID of the resource.
     */
    @JvmName("aygcucxalwlbuhvm")
    public suspend fun groupId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.groupId = mapped
    }

    /**
     * @param value The ID of the private link resource.
     */
    @JvmName("wogafxpyxlhbvjbp")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    /**
     * @param value The name of the private link resource.
     */
    @JvmName("shlexpvgfyvxrkch")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The RequiredMembers of the resource
     */
    @JvmName("ralrwewffyvosiya")
    public suspend fun requiredMembers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.requiredMembers = mapped
    }

    /**
     * @param values The RequiredMembers of the resource
     */
    @JvmName("anjkmslanrdxyiwv")
    public suspend fun requiredMembers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.requiredMembers = mapped
    }

    /**
     * @param value The resource type.
     */
    @JvmName("fddtjtenvjoacesr")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): PrivateLinkResourceArgs = PrivateLinkResourceArgs(
        groupId = groupId,
        id = id,
        name = name,
        requiredMembers = requiredMembers,
        type = type,
    )
}
